==> openshift-serverless-logic-1.27.0-src.zip: openshift-serverless-logic-1.27.0.GA-src/org.kie.kogito-kogito-apps-1.32.0.Final/ui-packages/packages/task-details/src/embedded/EmbeddedTaskDetails.tsx <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useCallback, useMemo } from 'react';
import {
  TaskDetailsApi,
  TaskDetailsChannelApi,
  TaskDetailsEnvelopeApi
} from '../api';
import { ContainerType } from '@kogito-tooling/envelope/dist/api';
import { EnvelopeServer } from '@kogito-tooling/envelope-bus/dist/channel';
import { EmbeddedEnvelopeFactory } from '@kogito-tooling/envelope/dist/embedded';
import { EnvelopeBusMessage } from '@kogito-tooling/envelope-bus/dist/api';
import { UserTaskInstance } from '@kogito-apps/task-console-shared';
import { init } from '../envelope';

export type Props = {
  targetOrigin: string;
  userTask: UserTaskInstance;
};

export const EmbeddedTaskDetails = React.forwardRef<TaskDetailsApi, Props>(
  (props, forwardedRef) => {
    const pollInit = useCallback(
      (
        // eslint-disable-next-line
        envelopeServer: EnvelopeServer<
          TaskDetailsChannelApi,
          TaskDetailsEnvelopeApi
        >,
        container: () => HTMLDivElement
      ) => {
        init({
          config: {
            containerType: ContainerType.DIV,
            envelopeId: envelopeServer.id
          },
          container: container(),
          bus: {
            postMessage<D, Type>(
              message: EnvelopeBusMessage<D, Type>,
              targetOrigin?: string,
              transfer?: any
            ) {
              window.parent.postMessage(message, '*', transfer);
            }
          }
        });
        return envelopeServer.envelopeApi.requests.taskDetails__init(
          {
            origin: envelopeServer.origin,
            envelopeServerId: envelopeServer.id
          },
          {
            task: props.userTask
          }
        );
      },
      [props.userTask]
    );

    const refDelegate = useCallback(
      (
        envelopeServer: EnvelopeServer<
          TaskDetailsChannelApi,
          TaskDetailsEnvelopeApi
        >
      ): TaskDetailsApi => {
        return {};
      },
      []
    );

    const EmbeddedEnvelope = useMemo(() => {
      return EmbeddedEnvelopeFactory({
        api: props,
        origin: props.targetOrigin,
        refDelegate,
        pollInit,
        config: { containerType: ContainerType.DIV }
      });
    }, []);

    return <EmbeddedEnvelope ref={forwardedRef} />;
  }
);

==> openshift-serverless-logic-1.30.0-src.zip: openshift-serverless-logic-1.30.0.GA-src/org.kie.kogito-kogito-apps-1.40.0.Final/ui-packages/packages/task-details/src/embedded/EmbeddedTaskDetails.tsx <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useCallback, useMemo } from 'react';
import {
  TaskDetailsApi,
  TaskDetailsChannelApi,
  TaskDetailsEnvelopeApi
} from '../api';
import { ContainerType } from '@kogito-tooling/envelope/dist/api';
import { EnvelopeServer } from '@kogito-tooling/envelope-bus/dist/channel';
import { EmbeddedEnvelopeFactory } from '@kogito-tooling/envelope/dist/embedded';
import { EnvelopeBusMessage } from '@kogito-tooling/envelope-bus/dist/api';
import { UserTaskInstance } from '@kogito-apps/task-console-shared';
import { init } from '../envelope';

export type Props = {
  targetOrigin: string;
  userTask: UserTaskInstance;
};

export const EmbeddedTaskDetails = React.forwardRef<TaskDetailsApi, Props>(
  (props, forwardedRef) => {
    const pollInit = useCallback(
      (
        // eslint-disable-next-line
        envelopeServer: EnvelopeServer<
          TaskDetailsChannelApi,
          TaskDetailsEnvelopeApi
        >,
        container: () => HTMLDivElement
      ) => {
        init({
          config: {
            containerType: ContainerType.DIV,
            envelopeId: envelopeServer.id
          },
          container: container(),
          bus: {
            postMessage<D, Type>(
              message: EnvelopeBusMessage<D, Type>,
              targetOrigin?: string,
              transfer?: any
            ) {
              window.parent.postMessage(message, targetOrigin, transfer);
            }
          }
        });
        return envelopeServer.envelopeApi.requests.taskDetails__init(
          {
            origin: envelopeServer.origin,
            envelopeServerId: envelopeServer.id
          },
          {
            task: props.userTask
          }
        );
      },
      [props.userTask]
    );

    const refDelegate = useCallback(
      (
        envelopeServer: EnvelopeServer<
          TaskDetailsChannelApi,
          TaskDetailsEnvelopeApi
        >
      ): TaskDetailsApi => {
        return {};
      },
      []
    );

    const EmbeddedEnvelope = useMemo(() => {
      return EmbeddedEnvelopeFactory({
        api: props,
        origin: props.targetOrigin,
        refDelegate,
        pollInit,
        config: { containerType: ContainerType.DIV }
      });
    }, []);

    return <EmbeddedEnvelope ref={forwardedRef} />;
  }
);
